==> estateplat-common-1.2.4-20211014.081132-912-sources.jar: cn/gtmap/estateplat/model/trade/JcptHtxx.java <==
package cn.gtmap.estateplat.model.trade;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Entity
@Table(name = "JCPT_HTXX")
public class JcptHtxx implements Serializable {
    @Id
    String ywid;
    String htbh;
    String spfzjk;
    String spfzjkdx;
    String bazt;
    byte[] htfj;
    Date jysj;
    String fwlx;
    String xqmc;
    String xz;

    public Date getJysj() {
        return jysj;
    }

    public void setJysj(Date jysj) {
        this.jysj = jysj;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getXz() {
        return xz;
    }

    public void setXz(String xz) {
        this.xz = xz;
    }

    public byte[] getHtfj() {
        return htfj;
    }

    public void setHtfj(byte[] htfj) {
        this.htfj = htfj;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getSpfzjk() {
        return spfzjk;
    }

    public void setSpfzjk(String spfzjk) {
        this.spfzjk = spfzjk;
    }

    public String getSpfzjkdx() {
        return spfzjkdx;
    }

    public void setSpfzjkdx(String spfzjkdx) {
        this.spfzjkdx = spfzjkdx;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }
}

==> estateplat-common-1.2.4-20230403.030238-1152-sources.jar: cn/gtmap/estateplat/model/trade/JcptHtxx.java <==
package cn.gtmap.estateplat.model.trade;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Entity
@Table(name = "JCPT_HTXX")
public class JcptHtxx implements Serializable {
    @Id
    String ywid;
    String htbh;
    String spfzjk;
    String spfzjkdx;
    String bazt;
    byte[] htfj;
    Date jysj;
    String fwlx;
    String xqmc;
    String xz;
    String cqzh;

    public Date getJysj() {
        return jysj;
    }

    public void setJysj(Date jysj) {
        this.jysj = jysj;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getXz() {
        return xz;
    }

    public void setXz(String xz) {
        this.xz = xz;
    }

    public byte[] getHtfj() {
        return htfj;
    }

    public void setHtfj(byte[] htfj) {
        this.htfj = htfj;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getSpfzjk() {
        return spfzjk;
    }

    public void setSpfzjk(String spfzjk) {
        this.spfzjk = spfzjk;
    }

    public String getSpfzjkdx() {
        return spfzjkdx;
    }

    public void setSpfzjkdx(String spfzjkdx) {
        this.spfzjkdx = spfzjkdx;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }
}
